@@ -39,6 +39,8 @@ extern "C" {
 #include <pan/icons/pan-pixbufs.h>
 #include "header-pane.h"
 #include "pad.h"
+#include "prefs-ui.h"
+#include "tango-colors.h"
 
 using namespace pan;
 
@@ -93,7 +95,6 @@ namespace
   {
     ICON_READ,
     ICON_UNREAD,
-    ICON_NEW,
     ICON_COMPLETE,
     ICON_COMPLETE_READ,
     ICON_INCOMPLETE,
@@ -109,7 +110,6 @@ namespace
    {
       { icon_article_read,           0 },
       { icon_article_unread,         0 },
-      { icon_article_new,            0 },
       { icon_binary_complete,        0 },
       { icon_binary_complete_read,   0 },
       { icon_binary_incomplete,      0 },
@@ -226,18 +226,18 @@ HeaderPane :: render_score (GtkTreeViewColumn * col,
   std::string bg, fg;
   if (score >= 9999) {
     fg = prefs.get_color_str ("score-color-watched-fg", "black");
-    bg = prefs.get_color_str ("score-color-watched-bg", "green");
+    bg = prefs.get_color_str ("score-color-watched-bg", TANGO_CHAMELEON_LIGHT);
   } else if (score >= 5000) {
     fg = prefs.get_color_str ("score-color-high-fg", "black");
-    bg = prefs.get_color_str ("score-color-high-bg", "yellow");
+    bg = prefs.get_color_str ("score-color-high-bg", TANGO_BUTTER_LIGHT);
   } else if (score >= 1) {
     fg = prefs.get_color_str ("score-color-medium-fg", "black");
-    bg = prefs.get_color_str ("score-color-medium-bg", "cyan");
+    bg = prefs.get_color_str ("score-color-medium-bg", TANGO_SKY_BLUE_LIGHT);
   } else if (score <= -9999) {
-    fg = prefs.get_color_str ("score-color-ignored-fg", "dark grey");
+    fg = prefs.get_color_str ("score-color-ignored-fg", TANGO_ALUMINUM_4);
     bg = prefs.get_color_str ("score-color-ignored-bg", "black");
   } else if (score <= -1) {
-    fg = prefs.get_color_str ("score-color-low-fg", "light grey");
+    fg = prefs.get_color_str ("score-color-low-fg", TANGO_ALUMINUM_2);
     bg = prefs.get_color_str ("score-color-low-bg", "black");
   }
 
@@ -1604,6 +1604,7 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   g_signal_connect (w, "popup-menu", G_CALLBACK(on_popup_menu), this);
   g_signal_connect (w, "row-activated", G_CALLBACK(on_row_activated), this);
   GtkWidget * scroll = gtk_scrolled_window_new (0, 0);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scroll), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_add (GTK_CONTAINER(scroll), w);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(scroll), GTK_SHADOW_IN);
 
