@@ -686,7 +686,7 @@ PostUI :: check_charset ()
                            _("There were problems with this post."),
                            msg);
   gtk_dialog_add_button (GTK_DIALOG(d), _("Go Back"), GTK_RESPONSE_CANCEL);
-  const int response = gtk_dialog_run (GTK_DIALOG(d));
+  gtk_dialog_run (GTK_DIALOG(d));
   gtk_widget_destroy (d);
   g_free (tmp);
   g_free (msg);
@@ -1202,7 +1202,7 @@ PostUI :: new_message_from_ui (Mode mode)
     profile.get_from_header (s);
     g_free (pch);
   }
-  g_mime_message_add_header (msg, "From", s.c_str());
+  g_mime_message_set_sender (msg, s.c_str());
 
   // headers from the ui: Subject
   const char * cpch (gtk_entry_get_text (GTK_ENTRY(_subject_entry)));
