@@ -116,44 +116,46 @@ namespace
                           const char     * text,
                           int              text_len)
   {
-    char * retval;
-    gssize out_len;
-    GMimeStream * in_stream;
-    GMimeStream * in_stream_filter;
-    GMimeFilter * charset_filter;
-    GMimeStream * out_stream;
-    GByteArray * byte_array;
+    char * retval (0);
+    GMimeFilter * charset_filter (g_mime_filter_charset_new (from_charset, to_charset));
 
-    /* set up an input stream with the desired charset filter */
-    in_stream = g_mime_stream_mem_new_with_buffer (text, text_len);
-    charset_filter = g_mime_filter_charset_new (from_charset, to_charset);
-    in_stream_filter = g_mime_stream_filter_new_with_stream (in_stream);
-    g_mime_stream_filter_add (GMIME_STREAM_FILTER(in_stream_filter), charset_filter);
+    if (charset_filter)
+    {
+      GMimeStream * in_stream;
+      GMimeStream * in_stream_filter;
+      GMimeStream * out_stream;
+      GByteArray * byte_array;
 
-    /* set up an output stream attached to a byte array */
-    byte_array = g_byte_array_new ();
-    out_stream = g_mime_stream_mem_new ();
-    g_mime_stream_mem_set_byte_array (GMIME_STREAM_MEM(out_stream), byte_array);
+      // set up an input stream with the desired charset filter
+      in_stream = g_mime_stream_mem_new_with_buffer (text, text_len);
+      in_stream_filter = g_mime_stream_filter_new_with_stream (in_stream);
+      g_mime_stream_filter_add (GMIME_STREAM_FILTER(in_stream_filter), charset_filter);
 
-    /* write the input stream to the output stream */
-    out_len = g_mime_stream_write_to_stream (in_stream_filter, out_stream);
+      // set up an output stream attached to a byte array
+      byte_array = g_byte_array_new ();
+      out_stream = g_mime_stream_mem_new ();
+      g_mime_stream_mem_set_byte_array (GMIME_STREAM_MEM(out_stream), byte_array);
 
-    /* if the write was successful, zero-terminate the string and return it. */
-    if (out_len < 0) {
-      retval = NULL;
-      g_byte_array_free (byte_array, TRUE);
-    } else {
-      g_byte_array_append (byte_array, (guint8*)"", 1);
-      retval = (gchar*) byte_array->data;
-      g_byte_array_free (byte_array, FALSE);
+      // write the input stream to the output stream
+      gssize out_len = g_mime_stream_write_to_stream (in_stream_filter, out_stream);
+
+      // if the write was successful, zero-terminate the string and return it.
+      if (out_len < 0) {
+        retval = NULL;
+        g_byte_array_free (byte_array, TRUE);
+      } else {
+        g_byte_array_append (byte_array, (guint8*)"", 1);
+        retval = (gchar*) byte_array->data;
+        g_byte_array_free (byte_array, FALSE);
+      }
+
+      // cleanup
+      g_object_unref (G_OBJECT(out_stream));
+      g_object_unref (G_OBJECT(in_stream_filter));
+      g_object_unref (G_OBJECT(charset_filter));
+      g_object_unref (G_OBJECT(in_stream));
     }
 
-    /* cleanup */
-    g_object_unref (G_OBJECT(out_stream));
-    g_object_unref (G_OBJECT(in_stream_filter));
-    g_object_unref (G_OBJECT(charset_filter));
-    g_object_unref (G_OBJECT(in_stream));
-
     return retval;
   }
 }
@@ -245,7 +247,7 @@ pan :: content_to_utf8 (const StringView  & content,
 
       // try each charset in turn
       foreach_const (strings_t, encodings, it) {
-        char * tmp = g_convert (content.str, content.len, "UTF-8", it->c_str(), 0, 0, 0);
+        char * tmp = g_mime_charset_strndup ("UTF-8", it->c_str(), content.str, content.len);
         if (tmp) {
           ret = tmp;
           g_free (tmp);
